package
Version:
v0.0.0-...-0d58064
Opens a new window with list of versions in this module.
Published: Jul 4, 2025
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Model represents the TUI model
New creates a new TUI model
Init initializes the model
type Refresher interface {
TriggerRefresh()
SetPaused(bool)
IsPaused() bool
}
Refresher interface for manual refresh capability
Source Files
¶
Click to show internal directories.
Click to hide internal directories.